#if !defined(CVTOCW_H)
#define CVTOCW_H

#if defined(__cplusplus)
extern "C" {
#endif

/* Symbolic names for the flags argument in the cvto*() family */

#define CVTO_NONE			(0)
#define CVTO_E_STYLE			(1 << 0)
#define CVTO_FILL_WITH_ZERO		(1 << 1)
#define CVTO_F_STYLE			(1 << 2)
#define CVTO_G_STYLE			(1 << 3)
#define CVTO_JUSTIFY_CENTER		(1 << 4)
#define CVTO_JUSTIFY_LEFT		(1 << 5)
#define CVTO_JUSTIFY_RIGHT		(1 << 6)
#define CVTO_SHOW_EXACT_ZERO		(1 << 7)
#define CVTO_SHOW_MIXEDCASE		(1 << 8)
#define CVTO_SHOW_PLUS			(1 << 9)
#define CVTO_SHOW_PLUS_AS_SPACE		(1 << 10)
#define CVTO_SHOW_POINT			(1 << 11)
#define CVTO_SHOW_SUBNORMAL		(1 << 12)
#define CVTO_SHOW_UPPERCASE		(1 << 13)
#define CVTO_TRIM_TRAILING_ZEROS	(1 << 14)

#define CVTO_FLAG_EQUALS		CVTO_JUSTIFY_CENTER
#define CVTO_FLAG_MINUS			CVTO_JUSTIFY_LEFT
#define CVTO_FLAG_PLUS			CVTO_SHOW_PLUS
#define CVTO_FLAG_SHARP			CVTO_SHOW_POINT
#define CVTO_FLAG_SLASH			CVTO_TRIM_TRAILING_ZEROS
#define CVTO_FLAG_SPACE			CVTO_SHOW_PLUS_AS_SPACE
#define CVTO_FLAG_ZERO			CVTO_FILL_WITH_ZERO

extern const char *(cvtobf)(float, int, int, int, int, int);
extern const char *(cvtodf)(float, int, int, int, int, int);
extern const char *(cvtogf)(float, int, int, int, int, int, int);
extern const char *(cvtohf)(float, int, int, int, int, int);
extern const char *(cvtoif)(float, int);
extern const char *(cvtonf)(float, int);
extern const char *(cvtoof)(float, int, int, int, int, int);

extern const char *(cvtob)(double, int, int, int, int, int);
extern const char *(cvtod)(double, int, int, int, int, int);
extern const char *(cvtog)(double, int, int, int, int, int, int);
extern const char *(cvtoh)(double, int, int, int, int, int);
extern const char *(cvtoi)(double, int);
extern const char *(cvton)(double, int);
extern const char *(cvtoo)(double, int, int, int, int, int);

#if defined(HAVE_LONG_DOUBLE)

extern const char *(cvtobl)(long double, int, int, int, int, int);
extern const char *(cvtodl)(long double, int, int, int, int, int);
extern const char *(cvtogl)(long double, int, int, int, int, int, int);
extern const char *(cvtohl)(long double, int, int, int, int, int);
extern const char *(cvtoil)(long double, int);
extern const char *(cvtonl)(long double, int);
extern const char *(cvtool)(long double, int, int, int, int, int);

#endif /* defined(HAVE_LONG_DOUBLE) */

#if defined(HAVE_LONG_LONG_DOUBLE)

extern const char *(cvtobll)(long_long_double, int, int, int, int, int);
extern const char *(cvtodll)(long_long_double, int, int, int, int, int);
extern const char *(cvtogll)(long_long_double, int, int, int, int, int, int);
extern const char *(cvtohll)(long_long_double, int, int, int, int, int);
extern const char *(cvtoill)(long_long_double, int);
extern const char *(cvtonll)(long_long_double, int);
extern const char *(cvtooll)(long_long_double, int, int, int, int, int);

#endif /* defined(HAVE_LONG_LONG_DOUBLE) */

#if defined(__ia64) && defined(__hpux) && defined(_FPWIDETYPES)

/* NB: _FPWIDETYPES is set by the HP-UX IA-64 compilers in response to
   the -fpwidetypes command-line option, and  */

/* Mimic the HP-UX practice in <float.h>, <math.h>, and <stdlib.h> of
   providing typedefs of the user types extended and quad if they are
   not yet defined. */

#ifndef _INCLUDE_QUAD
typedef __float128 quad;
#define _INCLUDE_QUAD
#endif

#ifndef _INCLUDE_EXTENDED
typedef __float80 extended;
#define _INCLUDE_EXTENDED
#endif

extern const char *(cvtobw)(__float80, int, int, int, int, int);
extern const char *(cvtodw)(__float80, int, int, int, int, int);
extern const char *(cvtogw)(__float80, int, int, int, int, int, int);
extern const char *(cvtohw)(__float80, int, int, int, int, int);
extern const char *(cvtoiw)(__float80, int);
extern const char *(cvtonw)(__float80, int);
extern const char *(cvtoow)(__float80, int, int, int, int, int);

extern const char *(cvtobq)(__float128, int, int, int, int, int);
extern const char *(cvtodq)(__float128, int, int, int, int, int);
extern const char *(cvtogq)(__float128, int, int, int, int, int, int);
extern const char *(cvtohq)(__float128, int, int, int, int, int);
extern const char *(cvtoiq)(__float128, int);
extern const char *(cvtonq)(__float128, int);
extern const char *(cvtooq)(__float128, int, int, int, int, int);

#endif /* defined(__ia64) && defined(__hpux) && defined(_FPWIDETYPES) */

#if defined(HAVE_DECIMAL)

extern const char *(cvtobdf)(decimal_float, int, int, int, int, int);
extern const char *(cvtoddf)(decimal_float, int, int, int, int, int);
extern const char *(cvtogdf)(decimal_float, int, int, int, int, int, int);
extern const char *(cvtohdf)(decimal_float, int, int, int, int, int);
extern const char *(cvtoidf)(decimal_float, int);
extern const char *(cvtondf)(decimal_float, int);
extern const char *(cvtoodf)(decimal_float, int, int, int, int, int);

extern const char *(cvtobd)(decimal_double, int, int, int, int, int);
extern const char *(cvtodd)(decimal_double, int, int, int, int, int);
extern const char *(cvtogd)(decimal_double, int, int, int, int, int, int);
extern const char *(cvtohd)(decimal_double, int, int, int, int, int);
extern const char *(cvtoid)(decimal_double, int);
extern const char *(cvtond)(decimal_double, int);
extern const char *(cvtood)(decimal_double, int, int, int, int, int);

#if defined(HAVE_DECIMAL_LONG_DOUBLE)

extern const char *(cvtobdl)(decimal_long_double, int, int, int, int, int);
extern const char *(cvtoddl)(decimal_long_double, int, int, int, int, int);
extern const char *(cvtogdl)(decimal_long_double, int, int, int, int, int, int);
extern const char *(cvtohdl)(decimal_long_double, int, int, int, int, int);
extern const char *(cvtoidl)(decimal_long_double, int);
extern const char *(cvtondl)(decimal_long_double, int);
extern const char *(cvtoodl)(decimal_long_double, int, int, int, int, int);

#endif /* defined(HAVE_DECIMAL_LONG_DOUBLE) */

#if defined(HAVE_DECIMAL_LONG_LONG_DOUBLE)

extern const char *(cvtobdll)(decimal_long_long_double, int, int, int, int, int);
extern const char *(cvtoddll)(decimal_long_long_double, int, int, int, int, int);
extern const char *(cvtogdll)(decimal_long_long_double, int, int, int, int, int, int);
extern const char *(cvtohdll)(decimal_long_long_double, int, int, int, int, int);
extern const char *(cvtoidll)(decimal_long_long_double, int);
extern const char *(cvtondll)(decimal_long_long_double, int);
extern const char *(cvtoodll)(decimal_long_long_double, int, int, int, int, int);

#endif /* defined(HAVE_DECIMAL_LONG_LONG_DOUBLE) */

#if 0

/* Temporary until binary, hexadecimal, and octal implementations
   completed for decimal floating-point arithmetic */
#define cvtobdf(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtohdf(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtoodf(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"

#define cvtobd(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtohd(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtood(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"

#define cvtobdl(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtohdl(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtoodl(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"

#define cvtobdll(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtohdll(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"
#define cvtoodll(x,w,p,e,g,f)	"[NOT YET IMPLEMENTED]"

#endif /* 0 */

#endif /* defined(HAVE_DECIMAL) */

#if defined(__cplusplus)
}
#endif

#endif /* !defined(CVTOCW_H) */
